@@ -1,13 +1,5 @@
 from pathlib import Path
-from typing import (
-    Tuple,
-    Dict,
-    List,
-    Iterable,
-    Optional,
-    Any,
-    Pattern
-)
+from typing import Tuple, Dict, List, Iterable, Optional, Any, Pattern
 
 import click
 import re
@@ -19,18 +11,19 @@ from robotidy.utils import (
     GlobalFormattingConfig,
     split_args_from_name_or_path,
     remove_rst_formatting,
-    RecommendationFinder
+    RecommendationFinder,
 )
+from robotidy.decorators import catch_exceptions
 from robotidy.version import __version__
 
 
-CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 HELP_MSG = f"""
 Version: {__version__}
 
 Robotidy is a tool for formatting Robot Framework source code.
 See examples at the end of this help message too see how you can use Robotidy.
-For more documentation check README section at https://github.com/MarketSquare/robotframework-tidy
+Full documentation available at https://robotidy.readthedocs.io .
 """
 EPILOG = """
 Examples:
@@ -59,13 +52,13 @@ class RawHelp(click.Command):
     def format_help_text(self, ctx, formatter):
         if self.help:
             formatter.write_paragraph()
-            for line in self.help.split('\n'):
+            for line in self.help.split("\n"):
                 formatter.write_text(line)
 
     def format_epilog(self, ctx, formatter):
         if self.epilog:
             formatter.write_paragraph()
-            for line in self.epilog.split('\n'):
+            for line in self.epilog.split("\n"):
                 formatter.write_text(line)
 
 
@@ -73,20 +66,14 @@ class TransformType(click.ParamType):
     name = "transform"
 
     def convert(self, value, param, ctx):
-        name = ''
-        try:
-            name, args = split_args_from_name_or_path(value.replace(' ', ''))
-        except ValueError:
-            exc = f'Invalid {name} transformer configuration. ' \
-                  f'Parameters should be provided in format name=value, delimited by :'
-            raise ValueError(exc)
+        name, args = split_args_from_name_or_path(value.replace(" ", ""))
         return name, args
 
 
 def parse_opt(opt):
-    while opt and opt[0] == '-':
+    while opt and opt[0] == "-":
         opt = opt[1:]
-    return opt.replace('-', '_')
+    return opt.replace("-", "_")
 
 
 def validate_config_options(params, config):
@@ -105,16 +92,15 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
     if value:
         config = read_pyproject_config(value)
     else:
-        config = find_and_read_config(ctx.params.get("src", ()))
+        config = find_and_read_config(ctx.params["src"] or (str(Path(".").resolve()),))
     if not config:
         return
     # Sanitize the values to be Click friendly. For more information please see:
     # https://github.com/psf/black/issues/1458
     # https://github.com/pallets/click/issues/1567
-    config = {
-        k: str(v) if not isinstance(v, (list, dict)) else v
-        for k, v in config.items()
-    }
+    config = {k: str(v) if not isinstance(v, (list, dict)) else v for k, v in config.items()}
+    if "src" in config:
+        config["src"] = tuple(config["src"])
     validate_config_options(ctx.command.params, config)
     default_map: Dict[str, Any] = {}
     if ctx.default_map:
@@ -141,7 +127,7 @@ def validate_regex(value: Optional[str]) -> Optional[Pattern]:
 def print_description(name: str):
     transformers = load_transformers(None, {}, allow_disabled=True)
     transformer_by_names = {transformer.__class__.__name__: transformer for transformer in transformers}
-    if name == 'all':
+    if name == "all":
         for tr_name, transformer in transformer_by_names.items():
             click.echo(f"Transformer {tr_name}:")
             click.echo(remove_rst_formatting(transformer.__doc__))
@@ -158,12 +144,15 @@ def print_description(name: str):
 
 def print_transformers_list():
     transformers = load_transformers(None, {}, allow_disabled=True)
-    click.echo('To see detailed docs run --desc <transformer_name> or --desc all. '
-               'Transformers with (disabled) tag \nare executed only when selected explicitly with --transform. '
-               'Available transformers:\n')
+    click.echo(
+        "To see detailed docs run --desc <transformer_name> or --desc all. "
+        "Transformers with (disabled) tag \nare executed only when selected explicitly with --transform or "
+        "configured with param `enabled=True`.\n"
+        "Available transformers:\n"
+    )
     transformer_names = []
     for transformer in transformers:
-        disabled = ' (disabled)' if not getattr(transformer, 'ENABLED', True) else ''
+        disabled = " (disabled)" if not getattr(transformer, "ENABLED", True) else ""
         transformer_names.append(transformer.__class__.__name__ + disabled)
     for name in sorted(transformer_names):
         click.echo(name)
@@ -171,29 +160,27 @@ def print_transformers_list():
 
 @click.command(cls=RawHelp, help=HELP_MSG, epilog=EPILOG, context_settings=CONTEXT_SETTINGS)
 @click.option(
-    '--transform',
-    '-t',
+    "--transform",
+    "-t",
     type=TransformType(),
     multiple=True,
-    metavar='TRANSFORMER_NAME',
-    help="Transform files from [PATH(S)] with given transformer"
+    metavar="TRANSFORMER_NAME",
+    help="Transform files from [PATH(S)] with given transformer",
 )
 @click.option(
-    '--configure',
-    '-c',
+    "--configure",
+    "-c",
     type=TransformType(),
     multiple=True,
-    metavar='TRANSFORMER_NAME:PARAM=VALUE',
-    help='Configure transformers'
+    metavar="TRANSFORMER_NAME:PARAM=VALUE",
+    help="Configure transformers",
 )
 @click.argument(
     "src",
     nargs=-1,
-    type=click.Path(
-        exists=True, file_okay=True, dir_okay=True, readable=True, allow_dash=True
-    ),
+    type=click.Path(exists=True, file_okay=True, dir_okay=True, readable=True, allow_dash=True),
     is_eager=True,
-    metavar='[PATH(S)]'
+    metavar="[PATH(S)]",
 )
 @click.option(
     "--exclude",
@@ -231,136 +218,131 @@ def print_transformers_list():
     help="Read configuration from FILE path.",
 )
 @click.option(
-    '--overwrite/--no-overwrite',
-    default=True,
-    help='Write changes back to file',
-    show_default=True
+    "--overwrite/--no-overwrite",
+    default=None,
+    help="Write changes back to file",
+    show_default=True,
 )
 @click.option(
-    '--diff',
+    "--diff",
     is_flag=True,
-    help='Output diff of each processed file.',
-    show_default=True
+    help="Output diff of each processed file.",
+    show_default=True,
 )
 @click.option(
-    '--check',
+    "--check",
     is_flag=True,
     help="Don't overwrite files and just return status. Return code 0 means nothing would change. "
-         "Return code 1 means that at least 1 file would change. Any internal error will overwrite this status.",
-    show_default=True
+    "Return code 1 means that at least 1 file would change. Any internal error will overwrite this status.",
+    show_default=True,
 )
 @click.option(
-    '-s',
-    '--spacecount',
+    "-s",
+    "--spacecount",
     type=click.types.INT,
     default=4,
-    help='The number of spaces between cells in the plain text format.\n',
-    show_default=True
+    help="The number of spaces between cells in the plain text format.\n",
+    show_default=True,
 )
 @click.option(
-    '-ls',
-    '--lineseparator',
-    type=click.types.Choice(['native', 'windows', 'unix']),
-    default='native',
+    "-ls",
+    "--lineseparator",
+    type=click.types.Choice(["native", "windows", "unix", "auto"]),
+    default="native",
     help="Line separator to use in outputs.\n"
-         "native:  use operating system's native line separators\n"
-         "windows: use Windows line separators (CRLF)\n"
-         "unix:    use Unix line separators (LF)",
-    show_default=True
+    "native:  use operating system's native line endings\n"
+    "windows: use Windows line endings (CRLF)\n"
+    "unix:    use Unix line endings (LF)\n"
+    "auto:    maintain existing line endings (uses what's used in the first line)",
+    show_default=True,
 )
 @click.option(
-    '-sl',
-    '--startline',
+    "--separator",
+    type=click.types.Choice(["space", "tab"]),
+    default="space",
+    help="Token separator to use in outputs.\n"
+    "space:   use --spacecount spaces to separate tokens\n"
+    "tab:     use a single tabulation to separate tokens\n",
+    show_default=True,
+)
+@click.option(
+    "-sl",
+    "--startline",
     default=None,
     type=int,
     help="Limit robotidy only to selected area. If --endline is not provided, format text only at --startline. "
-         "Line numbers start from 1.",
-    show_default=True
+    "Line numbers start from 1.",
+    show_default=True,
 )
 @click.option(
-    '-el',
-    '--endline',
+    "-el",
+    "--endline",
     default=None,
     type=int,
-    help="Limit robotidy only to selected area. "
-         "Line numbers start from 1.",
-    show_default=True
+    help="Limit robotidy only to selected area. " "Line numbers start from 1.",
+    show_default=True,
 )
 @click.option(
-    '--list',
-    '-l',
+    "--line-length",
+    default=120,
+    type=int,
+    help="Max allowed characters per line",
+    show_default=True,
+)
+@click.option(
+    "--list",
+    "-l",
     is_eager=True,
     is_flag=True,
-    help='List available transformers and exit.'
+    help="List available transformers and exit.",
 )
 @click.option(
-    '--desc',
-    '-d',
+    "--desc",
+    "-d",
     default=None,
-    metavar='TRANSFORMER_NAME',
-    help='Show documentation for selected transformer.'
+    metavar="TRANSFORMER_NAME",
+    help="Show documentation for selected transformer.",
 )
 @click.option(
-    '--output',
-    '-o',
-    type=click.Path(
-        file_okay=True, dir_okay=False, writable=True, allow_dash=False
-    ),
+    "--output",
+    "-o",
+    type=click.Path(file_okay=True, dir_okay=False, writable=True, allow_dash=False),
     default=None,
-    metavar='PATH',
-    help='Path to output file where source file will be saved'
+    metavar="PATH",
+    help="Path to output file where source file will be saved",
 )
+@click.option("-v", "--verbose", is_flag=True, help="More verbose output", show_default=True)
 @click.option(
-    '-v',
-    '--verbose',
+    "--force-order",
     is_flag=True,
-    help="More verbose output",
-    show_default=True
+    help="Transform files using transformers in order provided in cli",
 )
-@click.option(  # deprecated
-    '--list-transformers',
-    is_flag=True
-)
-@click.option(  # deprecated
-    '--describe-transformer',
-    default=None
-)
-@click.option(
-    '--force-order',
-    is_flag=True,
-    help='Transform files using transformers in order provided in cli'
-)
-@click.version_option(version=__version__, prog_name='robotidy')
+@click.version_option(version=__version__, prog_name="robotidy")
 @click.pass_context
+@catch_exceptions
 def cli(
-        ctx: click.Context,
-        transform: List[Tuple[str, List]],
-        configure: List[Tuple[str, List]],
-        src: Tuple[str, ...],
-        exclude: Optional[Pattern],
-        extend_exclude: Optional[Pattern],
-        overwrite: bool,
-        diff: bool,
-        check: bool,
-        spacecount: int,
-        lineseparator: str,
-        verbose: bool,
-        config: Optional[str],
-        startline: Optional[int],
-        endline: Optional[int],
-        list: bool,
-        desc: Optional[str],
-        output: Optional[Path],
-        list_transformers: bool,
-        describe_transformer: Optional[str],
-        force_order: bool
+    ctx: click.Context,
+    transform: List[Tuple[str, List]],
+    configure: List[Tuple[str, List]],
+    src: Tuple[str, ...],
+    exclude: Optional[Pattern],
+    extend_exclude: Optional[Pattern],
+    overwrite: bool,
+    diff: bool,
+    check: bool,
+    spacecount: int,
+    lineseparator: str,
+    verbose: bool,
+    config: Optional[str],
+    separator: Optional[str],
+    startline: Optional[int],
+    endline: Optional[int],
+    line_length: int,
+    list: bool,
+    desc: Optional[str],
+    output: Optional[Path],
+    force_order: bool,
 ):
-    if list_transformers:
-        print('--list-transformers is deprecated in 1.3.0. Use --list instead')
-        ctx.exit(0)
-    if describe_transformer:
-        print('--describe-transformer is deprecated in 1.3.0. Use --desc NAME instead')
-        ctx.exit(0)
     if list:
         print_transformers_list()
         ctx.exit(0)
@@ -368,20 +350,29 @@ def cli(
         return_code = print_description(desc)
         ctx.exit(return_code)
     if not src:
-        print("No source path provided. Run robotidy --help to see how to use robotidy")
-        ctx.exit(0)
+        if ctx.default_map is not None:
+            src = ctx.default_map.get("src", None)
+        if not src:
+            print("No source path provided. Run robotidy --help to see how to use robotidy")
+            ctx.exit(1)
 
     if exclude is None:
         exclude = re.compile(DEFAULT_EXCLUDES)
 
     if config and verbose:
-        click.echo(f'Loaded {config} configuration file')
+        click.echo(f"Loaded {config} configuration file")
+
+    if overwrite is None:
+        # None is default, with check not set -> overwrite, with check set -> overwrite only when overwrite flag is set
+        overwrite = not check
 
     formatting_config = GlobalFormattingConfig(
         space_count=spacecount,
         line_sep=lineseparator,
         start_line=startline,
-        end_line=endline
+        separator=separator,
+        end_line=endline,
+        line_length=line_length,
     )
     tidy = Robotidy(
         transformers=transform,
@@ -395,7 +386,7 @@ def cli(
         verbose=verbose,
         check=check,
         output=output,
-        force_order=force_order
+        force_order=force_order,
     )
     status = tidy.transform_files()
     ctx.exit(status)
